@@ -104,6 +104,42 @@ visualize(null_dist) +
 null_dist %>%
   get_p_value(obs_stat = x_tilde, direction = "two-sided")
 
+## -----------------------------------------------------------------------------
+set.seed(1)
+
+gss_paired <- gss %>%
+   mutate(
+      hours_previous = hours + 5 - rpois(nrow(.), 4.8),
+      diff = hours - hours_previous
+   )
+
+gss_paired %>%
+   select(hours, hours_previous, diff)
+
+## -----------------------------------------------------------------------------
+x_tilde <- gss_paired %>%
+  specify(response = diff) %>%
+  calculate(stat = "mean")
+
+## -----------------------------------------------------------------------------
+x_tilde <- gss_paired %>%
+  observe(response = diff, stat = "mean")
+
+## -----------------------------------------------------------------------------
+null_dist <- gss_paired %>%
+  specify(response = diff) %>%
+  hypothesize(null = "paired independence") %>% 
+  generate(reps = 1000, type = "permute") %>% 
+  calculate(stat = "mean")
+
+## -----------------------------------------------------------------------------
+visualize(null_dist) +
+  shade_p_value(obs_stat = x_tilde, direction = "two-sided")
+
+## -----------------------------------------------------------------------------
+null_dist %>%
+  get_p_value(obs_stat = x_tilde, direction = "two-sided")
+
 ## -----------------------------------------------------------------------------
 p_hat <- gss %>%
   specify(response = sex, success = "female") %>%
@@ -172,15 +208,18 @@ d_hat <- gss %>%
   calculate(stat = "diff in props", order = c("female", "male"))
 
 ## -----------------------------------------------------------------------------
-d_hat <- gss %>% 
-  observe(college ~ sex, success = "no degree", 
-          stat = "diff in props", order = c("female", "male"))
+d_hat <- gss %>%
+  observe(
+    college ~ sex,
+    success = "no degree",
+    stat = "diff in props", order = c("female", "male")
+  )
 
 ## -----------------------------------------------------------------------------
 null_dist <- gss %>%
   specify(college ~ sex, success = "no degree") %>%
-  hypothesize(null = "independence") %>% 
-  generate(reps = 1000) %>% 
+  hypothesize(null = "independence") %>%
+  generate(reps = 1000) %>%
   calculate(stat = "diff in props", order = c("female", "male"))
 
 ## -----------------------------------------------------------------------------
@@ -283,37 +322,49 @@ prop_test(gss,
 ## -----------------------------------------------------------------------------
 Chisq_hat <- gss %>%
   specify(response = finrela) %>%
-  hypothesize(null = "point",
-              p = c("far below average" = 1/6,
-                    "below average" = 1/6,
-                    "average" = 1/6,
-                    "above average" = 1/6,
-                    "far above average" = 1/6,
-                    "DK" = 1/6)) %>%
+  hypothesize(
+    null = "point",
+    p = c(
+      "far below average" = 1 / 6,
+      "below average" = 1 / 6,
+      "average" = 1 / 6,
+      "above average" = 1 / 6,
+      "far above average" = 1 / 6,
+      "DK" = 1 / 6
+    )
+  ) %>%
   calculate(stat = "Chisq")
 
 ## -----------------------------------------------------------------------------
 Chisq_hat <- gss %>%
-  observe(response = finrela,
-          null = "point",
-          p = c("far below average" = 1/6,
-                "below average" = 1/6,
-                "average" = 1/6,
-                "above average" = 1/6,
-                "far above average" = 1/6,
-                "DK" = 1/6),
-          stat = "Chisq")
+  observe(
+    response = finrela,
+    null = "point",
+    p = c(
+      "far below average" = 1 / 6,
+      "below average" = 1 / 6,
+      "average" = 1 / 6,
+      "above average" = 1 / 6,
+      "far above average" = 1 / 6,
+      "DK" = 1 / 6
+    ),
+    stat = "Chisq"
+  )
 
 ## -----------------------------------------------------------------------------
 null_dist <- gss %>%
   specify(response = finrela) %>%
-  hypothesize(null = "point",
-              p = c("far below average" = 1/6,
-                    "below average" = 1/6,
-                    "average" = 1/6,
-                    "above average" = 1/6,
-                    "far above average" = 1/6,
-                    "DK" = 1/6)) %>%
+  hypothesize(
+    null = "point",
+    p = c(
+      "far below average" = 1 / 6,
+      "below average" = 1 / 6,
+      "average" = 1 / 6,
+      "above average" = 1 / 6,
+      "far above average" = 1 / 6,
+      "DK" = 1 / 6
+    )
+  ) %>%
   generate(reps = 1000, type = "draw") %>%
   calculate(stat = "Chisq")
 
@@ -339,14 +390,18 @@ null_dist %>%
   get_p_value(obs_stat = Chisq_hat, direction = "greater")
 
 ## -----------------------------------------------------------------------------
-chisq_test(gss, 
-           response = finrela,
-           p = c("far below average" = 1/6,
-                 "below average" = 1/6,
-                 "average" = 1/6,
-                 "above average" = 1/6,
-                 "far above average" = 1/6,
-                 "DK" = 1/6))
+chisq_test(
+  gss,
+  response = finrela,
+  p = c(
+    "far below average" = 1 / 6,
+    "below average" = 1 / 6,
+    "average" = 1 / 6,
+    "above average" = 1 / 6,
+    "far above average" = 1 / 6,
+    "DK" = 1 / 6
+  )
+)
 
 ## -----------------------------------------------------------------------------
 Chisq_hat <- gss %>%
@@ -750,6 +805,36 @@ theor_ci
 visualize(sampling_dist) +
   shade_confidence_interval(endpoints = theor_ci)
 
+## -----------------------------------------------------------------------------
+d_hat <- gss %>%
+  specify(hours ~ college) %>%
+  calculate(stat = "ratio of means", order = c("degree", "no degree"))
+
+## -----------------------------------------------------------------------------
+d_hat <- gss %>%
+  observe(hours ~ college,
+          stat = "ratio of means", order = c("degree", "no degree"))
+
+## -----------------------------------------------------------------------------
+boot_dist <- gss %>%
+   specify(hours ~ college) %>%
+   generate(reps = 1000, type = "bootstrap") %>%
+   calculate(stat = "ratio of means", order = c("degree", "no degree"))
+
+## -----------------------------------------------------------------------------
+percentile_ci <- get_ci(boot_dist)
+
+## -----------------------------------------------------------------------------
+visualize(boot_dist) +
+  shade_confidence_interval(endpoints = percentile_ci)
+
+## -----------------------------------------------------------------------------
+standard_error_ci <- boot_dist %>%
+  get_ci(type = "se", point_estimate = d_hat)
+
+visualize(boot_dist) +
+  shade_confidence_interval(endpoints = standard_error_ci)
+
 ## -----------------------------------------------------------------------------
 t_hat <- gss %>%
   specify(hours ~ college) %>%
@@ -917,28 +1002,20 @@ obs_fit <- gss %>%
   fit()
 
 ## -----------------------------------------------------------------------------
-null_dist <- gss %>%
+boot_dist <- gss %>%
   specify(hours ~ age + college) %>%
-  hypothesize(null = "independence") %>%
-  generate(reps = 1000, type = "permute") %>%
-  fit()
-
-## -----------------------------------------------------------------------------
-null_dist2 <- gss %>%
-  specify(hours ~ age + college) %>%
-  hypothesize(null = "independence") %>%
-  generate(reps = 1000, type = "permute", variables = c(age, college)) %>%
+  generate(reps = 1000, type = "bootstrap") %>%
   fit()
 
 ## -----------------------------------------------------------------------------
 conf_ints <- 
   get_confidence_interval(
-    null_dist, 
+    boot_dist, 
     level = .95, 
     point_estimate = obs_fit
   )
 
 ## -----------------------------------------------------------------------------
-visualize(null_dist) +
+visualize(boot_dist) +
   shade_confidence_interval(endpoints = conf_ints)
 
