@@ -15,8 +15,10 @@ gss %>%
   ggplot2::ggplot() +
   ggplot2::aes(x = hours) +
   ggplot2::geom_histogram(bins = 20) +
-  ggplot2::labs(x = "hours: Number of Hours Worked",
-                y = "Number of Responses") +
+  ggplot2::labs(
+    x = "hours: Number of Hours Worked",
+    y = "Number of Responses"
+  ) +
   ggplot2::scale_x_continuous(breaks = seq(0, 90, 10))
 
 ## ----calc-obs-stat-1-sample, warning = FALSE, message = FALSE-----------------
@@ -36,9 +38,10 @@ null_dist_1_sample <- gss %>%
 ## ----visualize-1-sample, warning = FALSE, message = FALSE---------------------
 # visualize the null distribution and test statistic!
 null_dist_1_sample %>%
-  visualize() + 
+  visualize() +
   shade_p_value(observed_statistic,
-                direction = "two-sided")
+    direction = "two-sided"
+  )
 
 ## ----p-value-1-sample, warning = FALSE, message = FALSE-----------------------
 # calculate the p value from the test statistic and null distribution
@@ -60,7 +63,7 @@ observed_statistic <- gss %>%
   dplyr::pull()
 
 ## -----------------------------------------------------------------------------
-pt(observed_statistic, df = nrow(gss) - 1, lower.tail = FALSE)*2
+pt(unname(observed_statistic), df = nrow(gss) - 1, lower.tail = FALSE)*2
 
 ## ----plot-2-sample, echo = FALSE----------------------------------------------
 gss %>%
@@ -119,5 +122,5 @@ observed_statistic <- gss %>%
 observed_statistic
 
 ## -----------------------------------------------------------------------------
-pt(observed_statistic, df = nrow(gss) - 2, lower.tail = FALSE)*2
+pt(unname(observed_statistic), df = nrow(gss) - 2, lower.tail = FALSE)*2
 
