@@ -1,5 +1,3 @@
-context("hypothesize")
-
 one_mean <- mtcars_df %>%
   specify(response = mpg) %>% # formula alt: mpg ~ NULL
   hypothesize(null = "point", mu = 25)
@@ -61,11 +59,10 @@ test_that("auto `type` works (hypothesize)", {
 
 test_that(
   "hypothesize() throws an error when null is not point or independence", {
-  expect_error(
+  expect_snapshot(error = TRUE,
     mtcars_df %>%
       specify(response = mpg) %>%
-      hypothesize(null = "dependence"),
-    '`null` should be either "point" or "independence".'
+      hypothesize(null = "dependence")
   )
 })
 
@@ -73,7 +70,7 @@ test_that(
   "hypothesize() allows partial matching of null arg for point", {
   hyp_p <- mtcars_df %>%
     specify(response = mpg) %>%
-    hypothesize(null = "p", mu = 0)
+    hypothesize(null = "po", mu = 0)
   expect_equal(attr(hyp_p, "null"), "point")
 })
 
@@ -87,71 +84,73 @@ test_that(
 
 test_that(
   "hypothesize() throws an error when multiple null values are provided", {
-  expect_error(
+  expect_snapshot(error = TRUE,
     mtcars_df %>%
       specify(response = mpg) %>%
-      hypothesize(null = c("point", "independence")),
-    "You should specify exactly one type of null hypothesis"
+      hypothesize(null = c("point", "independence"))
   )
 })
 
 test_that(
   "hypothesize() throws an error when multiple params are set", {
-  expect_error(
+  expect_snapshot(error = TRUE,
     mtcars_df %>%
       specify(response = mpg) %>%
-      hypothesize(null = "point", mu = 25, med = 20),
-    "You must specify exactly one of `p`, `mu`, `med`, or `sigma`"
+      hypothesize(null = "point", mu = 25, med = 20)
   )
 })
 
 test_that(
   "hypothesize() throws a warning when params are set with independence", {
-  expect_warning(
-    mtcars_df %>%
+  expect_snapshot(
+    res_ <- mtcars_df %>%
       specify(mpg ~ vs) %>%
-      hypothesize(null = "independence", mu = 25),
-    'Parameter values are not specified when testing that two variables are independent.'
+      hypothesize(null = "independence", mu = 25)
   )
 })
 
+test_that(
+   "hypothesize() throws a warning when params are set with paired independence", {
+   expect_snapshot(
+      res_ <- mtcars_df %>%
+         specify(response = mpg) %>%
+         hypothesize(null = "paired independence", mu = 25)
+   )
+})
+
 test_that(
   "hypothesize() throws an error when p is greater than 1", {
-  expect_error(
-    mtcars_df %>%
+  expect_snapshot(error = TRUE,
+    res_ <- mtcars_df %>%
       specify(response = vs, success = "1") %>%
-      hypothesize(null = "point", p = 1 + .Machine$double.eps),
-    "`p` should only contain values between zero and one."
+      hypothesize(null = "point", p = 1 + .Machine$double.eps)
   )
 })
 
 test_that(
   "hypothesize() throws an error when p is less than 0", {
-  expect_error(
-    mtcars_df %>%
+  expect_snapshot(error = TRUE,
+    res_ <- mtcars_df %>%
       specify(response = vs, success = "1") %>%
-      hypothesize(null = "point", p = - .Machine$double.neg.eps),
-    "`p` should only contain values between zero and one."
+      hypothesize(null = "point", p = - .Machine$double.neg.eps)
   )
 })
 
 test_that(
   "hypothesize() throws an error when p contains missing values", {
-  expect_error(
-    mtcars_df %>%
+  expect_snapshot(error = TRUE,
+    res_ <- mtcars_df %>%
       specify(response = vs, success = "1") %>%
-      hypothesize(null = "point", p = c("0" = 0.5, "1" = NA_real_)),
-    "`p` should not contain missing values"
+      hypothesize(null = "point", p = c("0" = 0.5, "1" = NA_real_))
   )
 })
 
 test_that(
   "hypothesize() throws an error when vector p does not sum to 1", {
-  expect_error(
-    mtcars_df %>%
+  expect_snapshot(error = TRUE,
+    res_ <- mtcars_df %>%
       specify(response = vs, success = "1") %>%
-      hypothesize(null = "point", p = c("0" = 0.5, "1" = 0.5 + (eps *2))),
-    "Make sure the hypothesized values for the `p` parameters sum to 1. Please try again."
+      hypothesize(null = "point", p = c("0" = 0.5, "1" = 0.5 + (eps *2)))
   )
 })
 
@@ -160,35 +159,43 @@ test_that("hypothesize arguments function", {
   mtcars_s <- mtcars_f %>% specify(response = mpg)
   matrix1 <- matrix(data = NA, nrow = 3, ncol = 3)
 
-  expect_error(hypothesize(matrix1))
-  expect_error(hypothesize(mtcars_s, null = NA))
-  expect_error(hypothesize(mtcars_s))
+  expect_snapshot(error = TRUE, res_ <- hypothesize(matrix1))
+  expect_snapshot(error = TRUE, res_ <- hypothesize(mtcars_s, null = NA))
+  expect_snapshot(error = TRUE, res_ <- hypothesize(mtcars_s))
 
-  expect_error(mtcars_s %>% hypothesize(null = "point", mean = 3))
+  expect_snapshot(error = TRUE, res_ <- mtcars_s %>% hypothesize(null = "point", mean = 3))
+
+  expect_snapshot(error = TRUE, res_ <- mtcars_s %>% hypothesize(null = "independence"))
+  expect_snapshot(error = TRUE, res_ <- mtcars_s %>% hypothesize(null = "point"))
+
+  expect_snapshot(error = TRUE,
+    res_ <-
+       mtcars_f %>%
+       specify(mpg ~ am) %>%
+       hypothesize(null = "paired independence")
+  )
 
-  expect_error(mtcars_s %>% hypothesize(null = "independence"))
-  expect_error(mtcars_s %>% hypothesize(null = "point"))
   # Produces error on win-build
-#   expect_warning(
-#     mtcars_s %>% hypothesize(null = c("point", "independence"), mu = 3)
-#   )
-
-  expect_error(
-    mtcars_df %>% dplyr::select(vs) %>% hypothesize(null = "point", mu = 1)
+  expect_snapshot(error = TRUE,
+    res <- mtcars_s %>% hypothesize(null = c("point", "independence"), mu = 3)
   )
 
-  expect_error(
-    mtcars_df %>% specify(response = vs) %>% hypothesize(null = "point", mu = 1)
+  expect_snapshot(error = TRUE,
+    res_ <- mtcars_df %>% dplyr::select(vs) %>% hypothesize(null = "point", mu = 1)
   )
 
-  expect_error(mtcars_s %>% hypothesize(null = "point", p = 0.2))
+  expect_snapshot(error = TRUE,
+    res_ <- mtcars_df %>% specify(response = vs) %>% hypothesize(null = "point", mu = 1)
+  )
 
-  expect_error(mtcars_s %>% hypothesize())
+  expect_snapshot(error = TRUE, res_ <- mtcars_s %>% hypothesize(null = "point", p = 0.2))
+
+  expect_snapshot(error = TRUE, res_ <- mtcars_s %>% hypothesize())
 })
 
 test_that("params correct", {
-  expect_error(hypothesize(one_prop_specify, null = "point", mu = 2))
-  expect_error(hypothesize(one_mean_specify, null = "point", mean = 0.5))
+  expect_snapshot(error = TRUE, res_ <- hypothesize(one_prop_specify, null = "point", mu = 2))
+  expect_snapshot(error = TRUE, res_ <- hypothesize(one_mean_specify, null = "point", mean = 0.5))
 })
 
 test_that("sensible output", {
@@ -196,24 +203,23 @@ test_that("sensible output", {
 })
 
 test_that("user can specify multiple explanatory variables", {
-  x <- 
-    gss %>% 
+  x <-
+    gss %>%
     specify(hours ~ sex + college) %>%
     hypothesize(null = "independence")
-  
+
   expect_true(inherits(x, "infer"))
   expect_true(inherits(explanatory_variable(x), "tbl_df"))
   expect_true(inherits(explanatory_name(x), "character"))
   expect_true(inherits(explanatory_expr(x), "call"))
-  
+
   expect_equal(explanatory_name(x), c("sex", "college"))
   expect_equal(response_name(x), "hours")
-  
-  expect_warning(
-    gss %>% 
+
+  expect_snapshot(
+    res_ <- gss %>%
       specify(hours ~ sex + college) %>%
-      hypothesize(null = "independence", mu = 40),
-    "Parameter values are not specified when testing"
+      hypothesize(null = "independence", mu = 40)
   )
 })
 
